@@ -382,6 +382,39 @@ class Coordinates(object):
         """
         return len(self.translation)
 
+    @property
+    def x_axis(self):
+        """Return x axis vector of this coordinates.
+
+        Returns
+        -------
+        axis : numpy.ndarray
+            x axis.
+        """
+        return np.array(self.rotation[:, 0].T, 'f')
+
+    @property
+    def y_axis(self):
+        """Return y axis vector of this coordinates.
+
+        Returns
+        -------
+        axis : numpy.ndarray
+            y axis.
+        """
+        return np.array(self.rotation[:, 1].T, 'f')
+
+    @property
+    def z_axis(self):
+        """Return z axis vector of this coordinates.
+
+        Returns
+        -------
+        axis : numpy.ndarray
+            z axis.
+        """
+        return np.array(self.rotation[:, 2].T, 'f')
+
     def changed(self):
         """Return False
 
@@ -980,6 +1013,26 @@ class Coordinates(object):
         return self.newcoords(self.rotation, self.translation,
                               check_validity=False)
 
+    def orient_with_matrix(self, rotation_matrix, wrt='world'):
+        """Force update this coordinate system's rotation.
+
+        Parameters
+        ----------
+        rotation_matrix : numpy.ndarray
+            3x3 rotation matrix.
+        wrt : str or skrobot.coordinates.Coordinates
+            reference coordinates.
+        """
+        _check_valid_rotation(rotation_matrix)
+        if wrt == 'local' or wrt == self:
+            self._rotation = self._rotation.dot(rotation_matrix)
+        elif wrt == 'world':
+            self._rotation = rotation_matrix
+        elif isinstance(wrt, Coordinates):
+            self._rotation = wrt.worldrot().dot(rotation_matrix)
+        else:
+            raise TypeError('wrt {} not supported'.format(wrt))
+
     def copy(self):
         """Return a deep copy of the Coordinates."""
         return self.copy_coords()
@@ -1145,13 +1198,13 @@ class CascadedCoords(Coordinates):
     def descendants(self):
         return self._descendants
 
-    def assoc(self, child, relative_coords=None, force=False,
+    def assoc(self, child, relative_coords='world', force=False,
               **kwargs):
-        """Associate child coords to this coordinate.
+        """Associate child coords to this coordinate system.
 
-        If `relative_coords` is `None`, the translation and rotation
-        of childcoord in the world coordinate system do not change.
-        If `relative_coords` is specified, childcoord is assoced
+        If `relative_coords` is `None` or 'world', the translation and rotation
+        of childcoords in the world coordinate system do not change.
+        If `relative_coords` is specified, childcoords is assoced
         at translation and rotation of `relative_coords`.
         By default, if child is already assoced to some other coords,
         raise an exception. But if `force` is `True`, you can overwrite
@@ -1160,9 +1213,9 @@ class CascadedCoords(Coordinates):
         Parameters
         ----------
         child : CascadedCoords
-            child coordinate.
-        relative_coords : None or Coordinates
-            child coordinate's relative coordinate.
+            child coordinates.
+        relative_coords : None or Coordinates or str
+            child coordinates' relative coordinates.
         force : bool
             predicate for overwriting the existing assoc-relation
 
@@ -1170,6 +1223,39 @@ class CascadedCoords(Coordinates):
         -------
         child : CascadedCoords
             assoced child.
+
+        Examples
+        --------
+        >>> from skrobot.coordinates import CascadedCoords
+        >>> parent_coords = CascadedCoords(pos=[1, 0, 0])
+        >>> child_coords = CascadedCoords(pos=[1, 1, 0])
+        >>> parent_coords.assoc(child_coords)
+        #<CascadedCoords 0x7f1d30e29510 1.000 1.000 0.000 / 0.0 -0.0 0.0>
+        >>> child_coords.worldpos()
+        array([1., 1., 0.])
+        >>> child_coords.translation
+        array([0., 1., 0.])
+
+        `None` and 'world' have the same meaning.
+
+        >>> parent_coords = CascadedCoords(pos=[1, 0, 0])
+        >>> child_coords = CascadedCoords(pos=[1, 1, 0])
+        >>> parent_coords.assoc(child_coords, relative_coords='world')
+        #<CascadedCoords 0x7f1d30e29510 1.000 1.000 0.000 / 0.0 -0.0 0.0>
+        >>> child_coords.worldpos()
+        array([1., 1., 0.])
+
+        If `relative_coords` is 'local', `child` is associated at
+        world translation and world rotation of `child` from this coordinate
+        system.
+
+        >>> parent_coords = CascadedCoords(pos=[1, 0, 0])
+        >>> child_coords = CascadedCoords(pos=[1, 1, 0])
+        >>> parent_coords.assoc(child_coords, relative_coords='local')
+        >>> child_coords.worldpos()
+        array([2., 1., 0.])
+        >>> child_coords.translation
+        array([1., 1., 0.])
         """
         if 'c' in kwargs:
             warnings.warn(
@@ -1186,13 +1272,20 @@ class CascadedCoords(Coordinates):
             raise RuntimeError(msg)
 
         if not (child in self.descendants):
-            if relative_coords is None:
+            if relative_coords is None or relative_coords == 'world':
                 relative_coords = self.worldcoords().transformation(
                     child.worldcoords())
+            elif relative_coords == 'local':
+                relative_coords = child.worldcoords()
+            elif not isinstance(relative_coords, Coordinates):
+                raise TypeError(
+                    "`relative_coords`'s type should be"
+                    "skrobot.coordinates.Coordinates, but is {}"
+                    .format(type(relative_coords)))
             child.parent = self
             child.newcoords(relative_coords, check_validity=False)
             self._descendants.append(child)
-            return child
+        return child
 
     def dissoc(self, child):
         if child in self.descendants:
@@ -1297,6 +1390,39 @@ class CascadedCoords(Coordinates):
             return self.rotate_with_matrix(
                 rotation_matrix(theta, axis), wrt)
 
+    def orient_with_matrix(self, rotation_matrix, wrt='world'):
+        """Force update this coordinate system's rotation.
+
+        Parameters
+        ----------
+        rotation_matrix : numpy.ndarray
+            3x3 rotation matrix.
+        wrt : str or skrobot.coordinates.Coordinates
+            reference coordinates.
+        """
+        _check_valid_rotation(rotation_matrix)
+        if wrt == 'local' or wrt == self:
+            rotation = self._rotation.dot(rotation_matrix)
+        elif wrt == 'parent' or wrt == self.parent:
+            rotation = rotation_matrix
+        elif wrt == 'world':
+            # R_{input} = R_{world} = R_{parent} R_{this}
+            # R_{this} = R_{parent}^{-1} R_{input}
+            parent_worldcoords = self.parentcoords()
+            rotation = parent_worldcoords.rotation.T.dot(rotation_matrix)
+        elif isinstance(wrt, Coordinates):
+            # R_{world} = R_{wrt} R_{input}
+            # R_{world} = R_{parent} R_{this}
+            # R_{this} = R_{parent}^{-1} R_{world}
+            # R_{this} = R_{parent}^{-1} R_{world} R_{wrt} R_{input}
+            world_rotation_matrix = wrt.worldrot().dot(rotation_matrix)
+            parent_worldcoords = self.parentcoords()
+            rotation = parent_worldcoords.rotation.T.dot(world_rotation_matrix)
+        else:
+            raise TypeError('wrt {} not supported'.format(wrt))
+        return self.newcoords(rotation, self.translation,
+                              check_validity=False)
+
     def rotate_vector(self, v):
         return self.worldcoords().rotate_vector(v)
 
